==> haskell-hslogger-1.3.1.0-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslogger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslogger
version:              1.3.1.0
visibility:           public
id:                   hslogger-1.3.1.0-3MTG5t287UtFD1xik1KFg6
key:                  hslogger-1.3.1.0-3MTG5t287UtFD1xik1KFg6
license:              BSD-3-Clause
copyright:
    Copyright (c) 2004-2018 John Goerzen
    , (c) 2019      Herbert Valerio Riedel

maintainer:           hvr@gnu.org
author:               John Goerzen
homepage:             https://github.com/hvr/hslogger/wiki
synopsis:             Versatile logging framework
description:
    @hslogger@ is a logging framework for Haskell, roughly similar
    to [Python'\''s logging module](https://docs.python.org/2/library/logging.html).

    @hslogger@ lets each log message have a priority and source be associated
    with it.  The programmer can then define global handlers that route
    or filter messages based on the priority and source.  @hslogger@ also
    has a [Syslog](https://tools.ietf.org/html/rfc5424) handler built in.

category:             Interfaces
abi:                  cf51159b25a1467ce6b8d819f342d18f
exposed:              True
exposed-modules:
    System.Log System.Log.Formatter System.Log.Handler
    System.Log.Handler.Growl System.Log.Handler.Log4jXML
    System.Log.Handler.Simple System.Log.Handler.Syslog
    System.Log.Logger

hidden-modules:       UTF8
import-dirs:          /usr/lib/ghc-8.10.1/site-local/hslogger-1.3.1.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/hslogger-1.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/hslogger-1.3.1.0
hs-libraries:         HShslogger-1.3.1.0-3MTG5t287UtFD1xik1KFg6
depends:
    base-4.14.0.0 bytestring-0.10.10.0 containers-0.6.2.1
    deepseq-1.4.4.0 network-3.1.1.1-21cfXONzmdN6SdhuDmk3jf
    network-bsd-2.8.1.0-LW0btMZmSB9IBMSOak1kd
    old-locale-1.0.0.7-He1fhgasqBf2zFT9zlaLle time-1.9.3 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-hslogger/html/hslogger.haddock
haddock-html:         /usr/share/doc/haskell-hslogger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslogger-1.3.1.0-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslogger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslogger
version:              1.3.1.0
visibility:           public
id:                   hslogger-1.3.1.0-7dfcychV6ihFxFooK7MiCP
key:                  hslogger-1.3.1.0-7dfcychV6ihFxFooK7MiCP
license:              BSD-3-Clause
copyright:
    Copyright (c) 2004-2018 John Goerzen
    , (c) 2019      Herbert Valerio Riedel

maintainer:           hvr@gnu.org
author:               John Goerzen
homepage:             https://github.com/hvr/hslogger/wiki
synopsis:             Versatile logging framework
description:
    @hslogger@ is a logging framework for Haskell, roughly similar
    to [Python'\''s logging module](https://docs.python.org/2/library/logging.html).

    @hslogger@ lets each log message have a priority and source be associated
    with it.  The programmer can then define global handlers that route
    or filter messages based on the priority and source.  @hslogger@ also
    has a [Syslog](https://tools.ietf.org/html/rfc5424) handler built in.

category:             Interfaces
abi:                  021fd57754adf7034b4552a8f9b64d7e
exposed:              True
exposed-modules:
    System.Log System.Log.Formatter System.Log.Handler
    System.Log.Handler.Growl System.Log.Handler.Log4jXML
    System.Log.Handler.Simple System.Log.Handler.Syslog
    System.Log.Logger

hidden-modules:       UTF8
import-dirs:          /usr/lib/ghc-8.10.1/site-local/hslogger-1.3.1.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/hslogger-1.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/hslogger-1.3.1.0
hs-libraries:         HShslogger-1.3.1.0-7dfcychV6ihFxFooK7MiCP
depends:
    base-4.14.0.0 bytestring-0.10.10.0 containers-0.6.2.1
    deepseq-1.4.4.0 network-3.1.2.0-17TAgcOYpYlAVBy4dzi75o
    network-bsd-2.8.1.0-HBSI58e9fLQ18sZwPnd6Mx
    old-locale-1.0.0.7-He1fhgasqBf2zFT9zlaLle time-1.9.3 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-hslogger/html/hslogger.haddock
haddock-html:         /usr/share/doc/haskell-hslogger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
